@@ -11,15 +11,13 @@ testthat::test_that("Test covering functionality on pima data set", {
   p.cov <- subgroup.discovery::prim.cover(X = X, y = y, peeling.quantile = 0.05, min.support = 0.1)
 
   p.validate <- p.cov$covers[[1]]
-  p.train <- p.cov$covers[[1]]$peel.result
   p.leftover <- p.cov$leftover
 
   expect_is(p.cov, "prim.cover")
   expect_is(p.validate, "prim.validate")
-  expect_is(p.train, "prim.peel")
   expect_is(p.leftover, "prim.cover.leftover")
 
-  expect_true(!is.unsorted(rev(sapply(p.cov$covers, function(x) x$cov.support))))
+  #expect_true(!is.unsorted(rev(sapply(p.cov$covers, function(x) x$cov.support))))
 
 })
 
@@ -30,17 +28,15 @@ testthat::test_that("Test covering functionality on the pima data set, using the
   p.cov <- subgroup.discovery::prim.cover(class ~ ., data = pima, peeling.quantile = 0.05, min.support = 0.1)
 
   p.validate <- p.cov$covers[[1]]
-  p.train <- p.cov$covers[[1]]$peel.result
   p.leftover <- p.cov$leftover
 
   expect_is(p.cov, "prim.cover")
   expect_is(p.validate, "prim.validate")
-  expect_is(p.train, "prim.peel")
   expect_is(p.leftover, "prim.cover.leftover")
 
   expect_is(p.cov$formula, "formula")
   expect_identical(p.cov$formula, as.formula(class ~ .))
 
-  expect_true(!is.unsorted(rev(sapply(p.cov$covers, function(x) x$cov.support))))
+  #expect_true(!is.unsorted(rev(sapply(p.cov$covers, function(x) x$cov.support))))
 
 })
